-- main for textured_triangle.love

function love.load()
	gr, li, ky				= love.graphics, love.image, love.keyboard
	pi, sin, cos 			= math.pi, math.sin, math.cos
	gr.setCaption( 'Peppermint Lifesaver' )
	smallfont				= gr.newFont(18)
	gr.setFont( smallfont )
	bckgnd					= gr.newImage( 'MyTest1.jpg' )
	wd, ht					= gr.getWidth(),gr.getHeight()
	angle					= 0
	cx, cy					= wd/2, ht/2	-- location on screen
	factor					= 6				-- surface curvature
	size					= 1				-- object size
	load_object()
	load_effect()
	effect:send( 'factor', factor )
	info = {
			"Object Controls",
			"size:",
			"  <q><w>",
			"curvature:",
			"  <a><s>",
			"location:",
			"  X: <left><right>",
			"  Y: <up><down>"
			}
	end

function love.draw()
	gr.setColorMode( 'replace' )
	gr.draw( bckgnd )
	gr.setPixelEffect( effect )
		gr.draw( canvas, cx, cy, angle, size, size, cw/2,ch/2 )
		gr.setPixelEffect(  )
	gr.setColorMode( 'modulate' )
	gr.print( 'FPS: '..love.timer.getFPS(), wd - 100, 10 )
	key_options()
	show_data()
	end

function love.update( dt )
	angle		=  angle + dt
	if angle	>= 2*pi		then angle = angle - 2*pi	end
	if ky.isDown( 'left' )	then cx = cx - 1			end
	if ky.isDown( 'right' )	then cx = cx + 1			end
	if ky.isDown( 'up'	)	then cy = cy - 1			end
	if ky.isDown( 'down' )	then cy = cy + 1			end
	if ky.isDown( 'a' )		then factor = factor>0 and factor -.01 or 0 effect:send( 'factor', factor ) end
	if ky.isDown( 's' )		then factor = factor+.01 effect:send( 'factor', factor ) end
	if ky.isDown( 'w' )		then size	= size+.001		end
	if ky.isDown( 'q' )		then size	= size>.002 and size - .001 or .001 end
	end

function love.keypressed( key )
	if key == 'escape'	then love.event.push( 'quit' ) end
	end

function load_object()
	cw, ch					= 400, 400	-- size not critical
	canvas					= gr.newCanvas( cw, ch )
	canvas:renderTo( draw_object_onto_canvas )
	end

function draw_object_onto_canvas()
	gr.setColorMode( 'replace' )
	canvas:clear( 255, 255, 255, 0 )
	gr.setLineWidth( 2 )
	local ro, ri = cw/2, 0.6*cw/2		-- inner * outer radius
	gr.setColor( 255, 0, 255, 255 )
	for i = 0, 2*pi, pi/90 do
		gr.line( ri*sin(i)+cw/2, ri*cos(i)+ch/2, cw*(sin(i)+1)/2, ch*(cos(i)+1)/2 )
		end
	gr.setColor( 255, 0, 0, 255 )
	gr.setLineWidth( 15 )
	for i = 0, 2*pi, pi/8 do
		gr.line( ri*sin(i)+cw/2, ri*cos(i)+ch/2, cw*(sin(i)+1)/2, ch*(cos(i)+1)/2 )
		end
	end

function load_effect()
	effect = love.graphics.newPixelEffect [[
		extern float factor;
		float inner		= 0.3;
		float outer		= 0.5;
		float mid		= 0.4;
		float cnt		= 0.5;	// center of canvas
		vec4 effect(vec4 global_color, Image texture, vec2 tc, vec2 pc )
		{
		vec4 pixel		= Texel(texture, tc);
		float root		= sqrt((cnt-tc.x)*(cnt-tc.x)+(cnt-tc.y)*(cnt-tc.y));
		if (root		<= outer && root>= inner)
			{
			float adj	= 1 - factor * abs( root - mid );
			pixel.r		= clamp( adj * pixel.r, 0, 1 );
			pixel.g		= clamp( adj * pixel.g, 0, 1 );
			pixel.b		= clamp( adj * pixel.b, 0, 1 );
			pixel.a		= 1;
			}
		return pixel;
		}
		]]
	end

function key_options()
	gr.setColor( 255, 255, 0, 255 )
	for i = 1, #info do gr.print( info[i], 10, i * 20 ) end
	end

function show_data()
	gr.setColor( 255, 255, 0, 255 )
	data = {
		"Object Settings",
		"X location: "..cx,
		"Y location: "..cy,
		"size: "..math.floor( 100 * size ) / 100,
		"curvature: "..math.floor( 100 * factor ) / 100,
		"rotation angle: "..math.floor( angle * 180 / pi )
		}
	local x, y = 10, 20
	for i = 1, #data do
		gr.print( data[i], x, i * y + 420 )
		end
	end


